@@ -648,12 +648,11 @@ class fMMS_GUI(hildon.Program):
 		path = "file://" + data
 		# gnomevfs seems to be better than mimetype when guessing mimetype for us
 		file_mimetype = gnomevfs.get_mime_type(path)
-		file_mimetype = None
 		if file_mimetype != None:
 			if file_mimetype.startswith("video") or file_mimetype.startswith("audio"):
 				rpc = osso.Rpc(self.osso_c)
 				rpc.rpc_run("com.nokia.mediaplayer", "/com/nokia/mediaplayer", "com.nokia.mediaplayer", "mime_open", (str, path))	
-			elif file_mimetype.starts_with("image"):
+			elif file_mimetype.startswith("image"):
 				rpc = osso.Rpc(self.osso_c)
 				rpc.rpc_run("com.nokia.image_viewer", "/com/nokia/image_viewer", "com.nokia.image_viewer", "mime_open", (str, path))
 		else:
