@@ -104,8 +104,16 @@ class fMMS_GUI(hildon.Program):
 		self.contacts_dialog.set_default_size(-1, 320)
 			        			    
 		self.contacts_dialog.vbox.pack_start(selector)
+		self.contacts_dialog.add_button("Done", 1)
 		self.contacts_dialog.show_all()
-		ret = self.contacts_dialog.run()
+		while 1:
+			ret = self.contacts_dialog.run()
+			if ret == 1:
+				ret2 = self.contact_selector_changed(selector)
+				if ret2 == 0:
+					break
+			else:
+				break
 		self.contacts_dialog.destroy()
 		
 	def contact_number_chosen(self, button, nrdialog):
@@ -115,8 +123,7 @@ class fMMS_GUI(hildon.Program):
 		nrdialog.response(0)
 		self.contacts_dialog.response(0)
 		
-	def contact_selector_changed(self, selector, data):
-		print data
+	def contact_selector_changed(self, selector):
 		username = selector.get_current_text()
 		nrlist = self.ch.get_numbers_from_name(username)
 		print nrlist
@@ -129,12 +136,14 @@ class fMMS_GUI(hildon.Program):
 		nrdialog.show_all()
 		# this is blocking until we get a return
 		ret = nrdialog.run()
+		print "changed ret:", ret
 		nrdialog.destroy()
+		return ret
 	
 	def create_contacts_selector(self):
 		#Create a HildonTouchSelector with a single text column
-		selector = hildon.TouchSelector(text = True)
-		selector.connect("changed", self.contact_selector_changed)
+		selector = hildon.TouchSelectorEntry(text = True)
+		#selector.connect('changed', self.contact_selector_changed)
 
 		cl = self.ch.get_contacts_as_list()
 
