@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#
+# -*- coding: utf-8 -*-
 # This library is free software, distributed under the terms of
 # the GNU Lesser General Public License Version 2.
 # See the COPYING.LESSER file included in this archive
@@ -7,7 +7,14 @@
 # The docstrings in this module contain epytext markup; API documentation
 # may be created by processing this file with epydoc: http://epydoc.sf.net
 
-""" MMS Data Unit structure encoding and decoding classes """
+""" MMS Data Unit structure encoding and decoding classes 
+Original by Francois Aucamp
+Modified by Nick Leppänen Larsson for use in Maemo5/Fremantle on the Nokia N900.
+
+@author: Francois Aucamp <faucamp@csir.co.za>
+@author: Nick LeppÃ¤nen Larsson <frals@frals.se>
+@license: GNU LGPL
+"""
 
 import os, array
 import wsp_pdu
@@ -44,13 +51,13 @@ class MMSEncodingAssignments:
 
 class MMSDecoder(wsp_pdu.Decoder):
     """ A decoder for MMS messages """
-    def __init__(self, filename=None):
+    def __init__(self, filename=None, noHeaders=None):
         """ @param filename: If specified, decode the content of the MMS
                              message file with this name
             @type filename: str
         """
         self._mmsData = array.array('B')
-        self._mmsMessage = message.MMSMessage()
+        self._mmsMessage = message.MMSMessage(noHeaders)
         self._parts = []
         self._path = filename
 
@@ -126,11 +133,17 @@ class MMSDecoder(wsp_pdu.Decoder):
         # The next few headers will not be in a specific order, except for
         # "Content-Type", which should be the last header
         # According to [4], MMS header field names will be short integers
+        # If the message type is a M-Notification* or M-Acknowledge
+        #type we don't expect any ContentType and should break on
+        # StopIteration exception
         contentTypeFound = False
         contentLocationFound = False
         while (contentTypeFound == False):
-            header, value = self.decodeHeader(dataIter)
-            #print (header, value)
+            try:
+            	header, value = self.decodeHeader(dataIter)
+            except StopIteration, e:
+            	print e, e.args
+            	break
             if header == MMSEncodingAssignments.fieldNames[0x04][0]:
                 contentTypeFound = True
             elif header == MMSEncodingAssignments.fieldNames[0x03][0]:
@@ -138,8 +151,12 @@ class MMSDecoder(wsp_pdu.Decoder):
                 break
                 #pass
             else:
-                self._mmsMessage.headers[header] = value
-                #print '%s: %s' % (header, str(value))
+            	try:
+			self._mmsMessage.headers[header] = value
+			#print '%s: %s' % (header, str(value))
+		except StopIteration, e:
+			print e, e.args
+			break
         
         cType = value[0]
         #print '%s: %s' % (header, cType)
@@ -178,7 +195,7 @@ class MMSDecoder(wsp_pdu.Decoder):
 				    print 'A fatal error occurred, probably due to an unimplemented decoding operation. Tried to decode header: %s' % mmsFieldName
 				    raise
 			except wsp_pdu.DecodeError:
-				header, value = wsp_pdu.Decoder.decodeHeader(dataIter) #MMSDecoder.decodeApplicationHeader(byteIter)
+				mmsFieldName, mmsValue = wsp_pdu.Decoder.decodeHeader(dataIter) #MMSDecoder.decodeApplicationHeader(byteIter)
 			headers[mmsFieldName] = mmsValue
 		return headers
     
@@ -750,8 +767,9 @@ class MMSDecoder(wsp_pdu.Decoder):
         
     
 class MMSEncoder(wsp_pdu.Encoder):
-    def __init__(self):
-        self._mmsMessage = message.MMSMessage()
+    def __init__(self, noHeaders=None):
+        self.noHeaders = noHeaders
+        self._mmsMessage = message.MMSMessage(noHeaders)
     
     def encode(self, mmsMessage):
         """ Encodes the specified MMS message
@@ -764,7 +782,8 @@ class MMSEncoder(wsp_pdu.Encoder):
         """
         self._mmsMessage = mmsMessage
         msgData = self.encodeMessageHeader()
-        msgData.extend(self.encodeMessageBody())
+        if self.noHeaders == None:
+        	msgData.extend(self.encodeMessageBody())
         return msgData
     
     def encodeMessageHeader(self):
@@ -835,6 +854,8 @@ class MMSEncoder(wsp_pdu.Encoder):
         if 'MMS-Version' not in headersToEncode:
             headersToEncode['MMS-Version'] = '1.0'
         
+        messageType = headersToEncode['Message-Type']
+        
         # Encode the first three headers, in correct order
         for hdr in ('Message-Type', 'Transaction-Id', 'MMS-Version'):
             messageHeader.extend(MMSEncoder.encodeHeader(hdr, headersToEncode[hdr]))
@@ -848,12 +869,13 @@ class MMSEncoder(wsp_pdu.Encoder):
             messageHeader.extend(MMSEncoder.encodeHeader(hdr, headersToEncode[hdr]))
         
         # Ok, now only "Content-type" should be left
-        ctType = headersToEncode['Content-Type'][0]
-        ctParameters = headersToEncode['Content-Type'][1]
-        messageHeader.extend(MMSEncoder.encodeMMSFieldName('Content-Type'))
-        #print (ctType, ctParameters)
-        messageHeader.extend(MMSEncoder.encodeContentTypeValue(ctType, ctParameters))
-
+        # No content-type if it's a notifyresp-ind
+        if messageType != 'm-notifyresp-ind' and messageType != 'm-acknowledge-ind':
+		ctType = headersToEncode['Content-Type'][0]
+		ctParameters = headersToEncode['Content-Type'][1]
+		messageHeader.extend(MMSEncoder.encodeMMSFieldName('Content-Type'))
+		#print (ctType, ctParameters)
+		messageHeader.extend(MMSEncoder.encodeContentTypeValue(ctType, ctParameters))
         return messageHeader
     
     def encodeMessageBody(self):
@@ -1097,3 +1119,24 @@ class MMSEncoder(wsp_pdu.Encoder):
             return [messageTypes[messageType]]
         else:
             return [0x80]
+
+    @staticmethod
+    def encodeStatusValue(statusValue):
+        """ Defined in [4], section 7.2.#
+        
+        Used to encode the "Status" MMS header.
+        
+        @return: The encoded Status-value, or 0x84 ('Unrecognised') if none
+        @rtype: str
+        """
+        
+        statusValues = {'Expired' : 0x80,
+                        'Retrieved' : 0x81,
+                        'Rejected' : 0x82,
+                        'Deferred' : 0x83,
+                        'Unrecognised' : 0x84}
+        
+        if statusValue in statusValues:
+		return [statusValues[statusValue]]
+        else:
+		return [0x84]
\ No newline at end of file
