@@ -164,6 +164,7 @@ class PushHandler:
 		fname.close()
 
 	""" get the mms message from content-location """
+	""" thanks benaranguren on talk.maemo.org for patch including x-wap-profile header """
 	def _get_mms_message(self, location, transaction):
 		dirname = self._mmsdir + transaction
 		if not os.path.isdir(dirname):
@@ -187,19 +188,25 @@ class PushHandler:
 			# this seems to work like it should
 			# TODO: dont hardcode timeout
 			# god it would be nice with python2.6 for timeout= in urllib2
-			timeout = 20
+			timeout = 60
 			socket.setdefaulttimeout(timeout)
 			(proxyurl, proxyport) = self.config.get_proxy_from_apn()
+			
 			if proxyurl == "" or proxyurl == None:
 				print "connecting without proxy"
-				mmsdata = urllib2.urlopen(location)
+				#mmsdata = urllib2.urlopen(location)
 			else:
 				proxyfull = str(proxyurl) + ":" + str(proxyport)
 				print "connecting with proxy", proxyfull	
 				proxy = urllib2.ProxyHandler({"http": proxyfull})
 				opener = urllib2.build_opener(proxy)
-				mmsdata = opener.open(location)
+				#mmsdata = opener.open(location)
+				urllib2.install_opener(opener)
 				
+			headers = {'Profile:' : 'http://mms.frals.se/n900.rdf', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
+			req = urllib2.Request(location, headers=headers)
+			mmsdata = urllib2.urlopen(req)
+			
 			mmsdataall = mmsdata.read()
 			fp = open(dirname + "/message", 'w')
 			fp.write(mmsdataall)
@@ -363,7 +370,8 @@ class MMSSender:
 		fp.close()
 		### END TEMP CODE ###
 		
-		headers = {'Content-Type':'application/vnd.wap.mms-message', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
+		#headers = {'Content-Type':'application/vnd.wap.mms-message', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
+		headers = {'Content-Type':'application/vnd.wap.mms-message'}
 		if proxyurl == "" or proxyurl == None:
 			print "connecting without proxy"
 			mmsc = mmsc.replace("http://", "")
